<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2007 - 2018 JROX Technologies, Inc. All Rights Reserved.
| -------------------------------------------------------------------------    
| This script may be only used and modified in accordance to the license      
   
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - downline_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the functions for generating downline data
|
*/

class Downline_Model extends CI_Model {
	
	var $downline_members;
	
	function _get_upline($id = '', $comm_levels = 1)
	{
		/**
		 * generate an array with the users upline members
		 * @id integer the id of the member
 		 * @return array 
		 */
		 
		$members = array();
		$levels = array();
		$current = $id;
		
		for ($i = 1; $i <= $comm_levels; $i++)
		{
			 //first get the direct referring member
			
			if ($current != '0')
			{
				$sql = 'SELECT ' . $this->db->dbprefix('members') . '.*, ' . $this->db->dbprefix('members_groups') . '.group_id as affiliate_group_id,
						' . $this->db->dbprefix('affiliate_groups') . '.* FROM ' . $this->db->dbprefix('members') . ' 
						LEFT JOIN ' . $this->db->dbprefix('members_groups') . ' 
						ON (' . $this->db->dbprefix('members') . '.member_id = ' . $this->db->dbprefix('members_groups') . '.member_id)
						LEFT JOIN ' . $this->db->dbprefix('affiliate_groups') . '
						ON (' . $this->db->dbprefix('members_groups') . '.group_id = ' . $this->db->dbprefix('affiliate_groups') . '.group_id)
						WHERE ' . $this->db->dbprefix('members') . '.member_id = \'' . $current . '\'
						GROUP BY ' . $this->db->dbprefix('members') . '.member_id';
				
				
				$query = $this->db->query($sql);
				
				if ($query->num_rows() > 0)
				{
					//add the member data to the array
					$member = $query->result_array();
					array_push($members, $member[0]);
					array_push($levels, $i);
					//set the new affiliate
					$current = $member['0']['sponsor_id'];
				}
			}
		}
		
		$upline = combine_array($levels, $members);
		
		return $upline;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_sponsor_details($id = '')
	{
		$this->db->where('member_id', $id);
		$query = $this->db->get('members');
		
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _check_downline_details($mem_array = '', $admin = false, $api = '')
	{
		$data = '';
		$details = '';
		$link = 'javascript:void(0)';
		
		if ($this->config->item('sts_affiliate_allow_expandable_downlines') == 1)
		{
			$link = MEMBERS_ROUTE . '/downline/view/' . $mem_array['member_id'];
		}
		
		$mem_photo = base_url() . 'images/misc/downline_1.gif';
		if ($mem_array['status'] == '0')
		{
			$mem_photo = base_url() . 'images/misc/downline_inactive_1.gif';
		}
		
		if ($admin == true)
		{			
			$link = admin_url() . 'downline/view_downline/' . $mem_array['member_id'];
		}
		else
		{

			if ($this->config->item('sts_affiliate_show_downline_emails') == 1)
			{
				if (empty($api))
				{
					$details .= '<br />' . auto_link($mem_array['primary_email']);
				}
				else
				{
					$details .= '<br />' . $mem_array['primary_email'];
				}
			}
			
			if ($this->config->item('sts_affiliate_show_downline_details') == 1)
			{
				if (empty($api))
				{
					$details .= '<br /><a href="javascript:void(window.open(\'' . site_url() . MEMBERS_ROUTE . '/downline/member/' . $mem_array['member_id'] . '\', \'popup2\', \'width=500,height=300, location=no, menubar=yes, status=no,toolbar=no, scrollbars=yes, resizable=yes\'))">' . $this->lang->line('member_details') . '</a>';
				}
				else
				{
					$details .= '<br /><a href="' . site_url() . MEMBERS_ROUTE . '/downline/member/' . $mem_array['member_id'] . '" class="popupwindow" rel="windowCenter" target="_blank">' . $this->lang->line('member_details') . '</a>;';
				}
			}
	
		}
		
		$data = '<br /><a href="' . $link . '"><img src="' . $mem_photo . '" class="downline_image"/></a><br /><a href="' . $link . '">'. $this->_check_show_name($mem_array) . '</a>' .$details;	
		
		return $data;
		
	}
	
	// ------------------------------------------------------------------------
	
	function _check_show_name($mem_array = array())
	{
		if ($this->config->item('show_view_downline_usernames'))
		{
			$id = $this->config->item('show_view_downline_usernames');
			return $mem_array[$id];	
		}
		
		return $mem_array['fname'].' ' . $mem_array['lname'];	
	}
	
	// ------------------------------------------------------------------------
	
	function _generate_downline($id = '0', $admin = false, $type = 'table')
	{
		/**
		 * generate the table that shows all downline members
		 * @id integer the id of the member
 		 * @return string or array
		 */
		 
		 //lets get the first row of referrals first for level 1 and level 2
		 
		 $sdata['results'] = $type == 'table' ? '' : array();
		 $sdata['levels'] = '';
		 $total = '0';
		 
		 $sql = 'SELECT status, member_id, sponsor_id, fname, lname, username, facebook_id, primary_email FROM ' . $this->db->dbprefix('members') . '
				WHERE sponsor_id = \'' . $id . '\'';
		 
		 if ($admin == false && $this->config->item('sts_affiliate_show_active_downline_users') == '1')
		 {
			$sql .= ' AND status = \'1\''; 
		 }
		 
		 $first_row = $this->db->query($sql);
		
		 if ($first_row->num_rows() > 0)
		 {
		 	$total = $first_row->num_rows();
			
			if ($admin == true)
			{
				$sdata['levels'] = $this->config->item('member_admin_default_downline_view');
			}
			else
			{
				$sdata['levels'] = $this->config->item('sts_site_showcase_multiple_programs') == 1 ? $this->config->item('sts_affiliate_commission_levels_restrict_view') : $this->config->item('prg_commission_levels_restrict_view') ;
			}
			 //generate the table for commission levels less than 3
			 if ($sdata['levels'] < 3)
			 {
				$this->original_array = $first_row->result_array();
				
				if ($type == 'table') //return a formatted table
				{
					foreach ($first_row->result_array() as $value)
					{
						$sdata['results'] .= '<td align="center" class="downline_top"><table width="100%" border="0" cellspacing="0" cellpadding="5">
										  <tr>
											<td align="center"><div class="downline_box">' . 
												$this->_check_downline_details($value, $admin)
											. '</div></td>
										  </tr>
										</table></td>';
					}
				}
				else //just return an array
				{
					$sdata['results'] = $first_row->result_array();
				}
			 }
			 else //get the entire dowline over 3 levels
			 {
				//get all users first
				$this->original_array = $this->_get_downline_users($id, $admin);
				
				if ($sdata['levels'] >= 3)
				{
					
					foreach ($first_row->result_array() as $value)
					{
	
						$query3 = $this->_downline_calc($this->original_array, $value['member_id']);
						$total3 = count($query3);
						
						if ($type == 'table')
						{
							$sdata['results'] .='<td align="center" class="downline_top" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="5">
									<tr>
									<td align="center" valign="top">
										<div class="downline_box">' . 
											$this->_check_downline_details($value, $admin)
										. '</div>
									</tr>';
						}
						else
						{
							array_push($sdata['results'], $value);
						}
							
						if ($total3 > 0)
						{
					
							$total = $total + $total3;
							if ($type == 'table')
							{
								$sdata['results'] .= '<tr>
											<td align="center" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="5">
										  <tr>';
							}	
								$level_4 = array();
								foreach ($query3 as $row3)
								{
									if ($type == 'table')
									{
										$sdata['results'] .= '<td align="center" class="downline_top" valign="top">
										<div class="downline_box">' . 
												$this->_check_downline_details($row3, $admin)
											. '</div>
										</td>';
									}
									else
									{
										array_push($sdata['results'], $row3);
									}
									
									array_push($level_4, $row3['member_id']);
								}
								
								if ($sdata['levels'] >= 4)
								{
									if ($type == 'table')
									{
										$sdata['results'] .= '<tr>';
									}
																	
									foreach ($level_4 as $value4)
									{
										if ($type == 'table')
										{
											$sdata['results'] .= '<td align="center" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="5">
													  <tr>';
										}
										
										$query4 = $this->_downline_calc($this->original_array, $value4);
										
										$level_5 = array();
										
										$total4 = count($query4);
										
										if ($total4 > 0)
										{
											$total = $total + $total4;
											
											foreach ($query4 as $row4)
											{
												if ($type == 'table')
												{
													$sdata['results'] .= '<td valign="top" align="center" class="downline_top">
													<div class="downline_box">' . 
													$this->_check_downline_details($row4, $admin)
													. '</div>
													</td>';
												}
												else
												{
													array_push($sdata['results'], $row4);
												}
												array_push($level_5, $row4['member_id']);	
											}
											
											if ($sdata['levels'] >= 5)
											{
												if ($type == 'table')
												{
													$sdata['results'] .= '<tr>';
												}
																							
												foreach ($level_5 as $value5)
												{
													if ($type == 'table')
													{
														$sdata['results'] .= '<td align="center" valign="top">
														<table width="100%" border="0" cellspacing="0" cellpadding="5">
													  	<tr>';
													 }
													 
													$query5 = $this->_downline_calc($this->original_array, $value5);
													
													$level_6 = array(); 
													
													$total5 = count($query5);
													
													if ($total5 > 0)
													{
														$total = $total + $total5;
														
														foreach ($query5 as $row5)
														{
															if ($type == 'table')
															{
																$sdata['results'] .= '<td valign="top" align="center" class="downline_top">
																<div class="downline_box">' . 
																$this->_check_downline_details($row5, $admin)
																. '</div>
																</td>';
															}
															else
															{
																array_push($sdata['results'], $row5);
															}
															
															array_push($level_6, $row5['member_id']);	
														}
														
														if ($sdata['levels'] >= 6)
														{
															if ($type == 'table')
															{
																$sdata['results'] .= '<tr>';
															}
															
															foreach ($level_6 as $value6)
															{
																if ($type == 'table')
																{
																	$sdata['results'] .= '<td align="center" valign="top">
																	<table width="100%" border="0" cellspacing="0" cellpadding="5">
																  	<tr>';
																 }
																
																$query6 = $this->_downline_calc($this->original_array, $value6);
																
																$level_7 = array(); 
																
																$total6 = count($query6);
																
																if ($total6 > 0)
																{
																	$total = $total + $total6;
																	
																	foreach ($query6 as $row6)
																	{
																		if ($type == 'table')
																		{
																			$sdata['results'] .= '<td valign="top" align="center" class="downline_top">
																			<div class="downline_box">' . 
																			$this->_check_downline_details($row6, $admin)
																		. '</div>
																			</td>';
																		}
																		else
																		{
																			array_push($sdata['results'], $row6);
																		}
																		
																		array_push($level_7, $row6['member_id']);	
																	}
																	
																	if ($sdata['levels'] >= 7)
																	{
																		if ($type == 'table')
																		{
																			$sdata['results'] .= '<tr>';
																		}
																		
																		foreach ($level_7 as $value7)
																		{
																			
																			if ($type == 'table')
																			{
																				$sdata['results'] .= '<td align="center" valign="top">
																				<table width="100%" border="0" cellspacing="0" cellpadding="5">
																			  	<tr>';
																			}
																			 
																			$query7 = $this->_downline_calc($this->original_array, $value7);
																			
																			$level_8 = array(); 
																			
																			$total7 = count($query7);
																			
																			if ($total7 > 0)
																			{
																				$total = $total + $total7;
																				foreach ($query7 as $row7)
																				{
																					if ($type == 'table')
																					{
																						$sdata['results'] .= '<td valign="top" align="center" class="downline_top">
																						<div class="downline_box">' . 
																						$this->_check_downline_details($row7, $admin)
																						. '</div></td>';
																					}
																					else
																					{
																						array_push($sdata['results'], $row7);
																					}
																					
																					array_push($level_8, $row7['member_id']);	
																				}
																				
																				if ($sdata['levels'] >= 8)
																				{
																					if ($type == 'table')
																					{
																						$sdata['results'] .= '<tr>';
																					}
																					
																					foreach ($level_8 as $value8)
																					{
																						if ($type == 'table')
																						{
																							$sdata['results'] .= '<td align="center" valign="top">
																							<table width="100%" border="0" cellspacing="0" cellpadding="5">
																						  	<tr>';
																						 }
																						 
																						$query8 = $this->_downline_calc($this->original_array, $value8);
																						
																						$level_9 = array(); 
																						
																						$total8 = count($query8);
																						
																						if ($total8 > 0)
																						{
																							$total = $total + $total8;
																							foreach ($query8 as $row8)
																							{
																								if ($type == 'table')
																								{
																									$sdata['results'] .= '<td valign="top" align="center" class="downline_top">
																									<div class="downline_box">' . 
																									$this->_check_downline_details($row8, $admin)
																									. '</div></td>';
																								}
																								else
																								{
																									array_push($sdata['results'], $row8);
																								}
																								
																								array_push($level_9, $row8['member_id']);	
																							}
																							
																							if ($sdata['levels'] >= 9)
																							{
																								if ($type == 'table')
																								{
																									$sdata['results'] .= '<tr>';
																								}
																								
																								foreach ($level_9 as $value9)
																								{
																									if ($type == 'table')
																									{
																										$sdata['results'] .= '<td align="center" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="5">
																									 	<tr>';
																									 } 
																									$query9 = $this->_downline_calc($this->original_array, $value9);
																									
																									$level_10 = array(); 
																									$total9 = count($query9);
																									
																									if ($total9 > 0)
																									{
																										$total = $total + $total9;
																										foreach ($query9 as $row9)
																										{
																											if ($type == 'table')
																											{
																												$sdata['results'] .= '<td valign="top" align="center" class="downline_top"><div class="downline_box">' . 
																												$this->_check_downline_details($row9, $admin)
																												. '</div></td>';
																											}
																											else
																											{
																												array_push($sdata['results'], $row9);
																											}
																											
																											array_push($level_10, $row9['member_id']);	
																										}
																										
																										if ($sdata['levels'] == 10)
																										{
																											if ($type == 'table')
																											{
																												$sdata['results'] .= '<tr>';
																											}
																											
																											foreach ($level_10 as $value10)
																											{
																												if ($type == 'table')
																												{
																													$sdata['results'] .= '<td align="center" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="5">
																												  <tr>';
																												}
																													
																												$query10 = $this->_downline_calc($this->original_array, $value10);
																												
																												$total10 = count($query10);
																												
																												if ($total10 > 0)
																												{
																													$total = $total + $total10;
																													foreach ($query10 as $row10)
																													{
																														if ($type == 'table')
																														{
																															$sdata['results'] .= '<td valign="top" align="center" class="downline_top"><div class="downline_box">' . 
																															$this->_check_downline_details($row10, $admin)
																															. '</div></td>';
																														}
																														else
																														{
																															array_push($sdata['results'], $row10);
																														}
																													}
																												}
																												else
																												{
																													if ($type == 'table')
																													{
																														$sdata['results'] .= '<td valign="top" align="center">&nbsp;</td>';
																													}	
																												}
																												
																												if ($type == 'table')
																												{
																													$sdata['results'] .= '</tr>
																															</table></td>';
																												}
																											}
																										}
																									}
																									else
																									{
																										if ($type == 'table')
																										{
																											$sdata['results'] .= '<td valign="top" align="center">&nbsp;</td>';
																										}
																									}
																									
																									if ($type == 'table')
																									{
																										$sdata['results'] .= '</tr>
																												</table></td>';
																									}
																								}
																							}
																						}
																						else
																						{
																							if ($type == 'table')
																							{
																								$sdata['results'] .= '<td valign="top" align="center">&nbsp;</td>';
																							}
																						}
																						
																						if ($type == 'table')
																						{
																							$sdata['results'] .= '</tr>
																									</table></td>';
																						}
																					}
																				}	
																			}
																			else
																			{
																				if ($type == 'table')
																				{
																					$sdata['results'] .= '<td valign="top" align="center">&nbsp;</td>';
																				}
																			}
																			
																			if ($type == 'table')
																			{
																				$sdata['results'] .= '</tr>
																						</table></td>';
																			}
																		}
																	}
																}
																else
																{
																	if ($type == 'table')
																	{
																		$sdata['results'] .= '<td valign="top" align="center">&nbsp;</td>';
																	}
																}
																if ($type == 'table')
																{
																	$sdata['results'] .= '</tr>
																	</table></td>';
																}
															}
														}
													}
													else
													{
														if ($type == 'table')
														{
															$sdata['results'] .= '<td valign="top" align="center">&nbsp;</td>';
														}
													}
													if ($type == 'table')
													{
														$sdata['results'] .= '</tr>
														</table></td>';
													}
												}
											}
										}
										else
										{
											if ($type == 'table')
											{
												$sdata['results'] .= '<td valign="top" align="center">&nbsp;</td>';
											}
										}
										
										if ($type == 'table')
										{
											$sdata['results'] .= '</tr>
														</table></td>';
										}
									}
									
								}	
								if ($type == 'table')
								{
									$sdata['results'] .= '</tr></table></td>
										  </tr>';
								}		  
						}
						
						if ($type == 'table')
						{
							$sdata['results'] .= '</table></td>';
						}
					}
				}
			 }
		
		}
		else
		{
			if ($type == 'table')
			{
				$sdata['results'] = '<td align="center">' . $this->lang->line('no_downline_members_found') . '</td>';
			}
		}
		
		$sdata['total_users'] = $total;
		
		return $sdata;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_downline_users($id = '', $admin = false)
	{
		 $sql = 'SELECT status, member_id, sponsor_id, fname, lname, username, facebook_id, primary_email FROM ' . $this->db->dbprefix('members') . '
				WHERE member_id != \'' . $id . '\'
				AND sponsor_id > \'0\'';
		 
		 if ($admin == false && $this->config->item('sts_affiliate_show_active_downline_users') == '1')
		 {
			$sql .= ' AND status = \'1\''; 
		 }
		 
		 $query = $this->db->query($sql);
	
		if ($query->num_rows() > 0)
		{
			return $query->result_array();
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _downline_calc($arr = '', $item = '')
	{
		/**
		 * generate the table that shows all downline members
		 * @arr members array
		 * @item level array
		 * @id column to query
 		 * @return array
		 */
		 
		
		$result = array();
	
		for ($i = 0; $i <= count($arr); $i++)
		{
			if (!empty($arr[$i]))
			{
				if (strcmp($arr[$i]['sponsor_id'], $item) == 0)
				{
					array_push($result, $arr[$i]);
					//unset ($arr[$i]);
				}
			}
			
		}
		
		//$this->original_array = $arr;
	
		return($result);
	}
	
	// ------------------------------------------------------------------------
	
	function _show_downline_list($id = '')
	{
		$users = $this->_generate_downline($id, false, 'email');	
	
		$list = $this->_get_children2($id, $users['results']);
		
		echo $this->array2ul ($list);
	}
	
	// ------------------------------------------------------------------------
	
	function array2ul($array = array(), $class = 'list') 
	{
		$out = '<ul class="' . $class .'">';
		foreach($array as $key => $elem)
		{
			if(!is_array($elem))
			{
				$u = explode('-', $elem);
				$out=$out.'<li><a href="'.site_url('members') . '/downline/details/' . $u[0] . '/' . url_title(strtolower($u[1])) . '">' . $u[1] . '</a></li>';
			}
			else 
			{ 	$u = explode('-', $key);
				$out=$out.'<li><a href="'.site_url('members') . '/downline/details/' . $u[0] . '/' . url_title(strtolower($u[1])) . '">' . $u[1] . '</a>' . $this->array2ul($elem).'</li>'; 
			}
		}
		
		$out=$out."</ul>";
		return $out; 
	}

	// ------------------------------------------------------------------------
	
	function _get_children2($id = '0', $users = '')
	{
		//select all children for this level		
		$array = array_match_values($users, 'sponsor_id', $id);
		
		if (empty($tree))
		{
			$tree = array();
		}
		
		if (count($array) > 0) 
		{			
			foreach ($array as $key => $value)
			{	
				$str = $value['member_id'] . '-' . $value['username'] . '-' . $value['fname'] . '-' . $value['lname'];
				
				$temp =  $this->_get_children2($value['member_id'], $users);					
				
				if (is_array($temp))
				{
					$tree[$str] = $temp;
				}
				else
				{
					$tree[] = $str;	
				}
			}	
		}
		
		return $tree;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_matrix_sponsor($sponsor = '', $user = '1')
	{
		$s = $this->_calc_sponsor_matrix($sponsor, '1');
		
		return $s;
	}
	
	// ------------------------------------------------------------------------
	
	function _calc_sponsor_matrix($sponsor = '', $level = 1)
	{
		$width = $this->config->item('sts_affiliate_mlm_matrix_width');
		$levels = $this->config->item('prg_commission_levels');

		$array = array();
		while ($level <= $levels)
		{
			$a = $this->_get_direct_downline($sponsor);

			if (count($a) >= $width) 
			{ 
				$array[2] = array(); 
				foreach ($a as $row) {  array_push($array[2], $row); } //2
				$level++;  //2
				if ($level <= $levels)
				{
					$array[3] = array(); 
					foreach ($array[2] as $row2) 
					{ 
						$b = $this->_get_direct_downline($row2['mid']); 
						if (count($b) < $width) { return $row2['mid']; }
						foreach ($b as $row) {  array_push($array[3], $row); } //3	
					} 
					$level++;  
					if ($level <= $levels)
					{
						$array[4] = array(); 
						foreach ($array[3] as $row3) 
						{ 
							$c = $this->_get_direct_downline($row3['mid']); 
							if (count($c) < $width) { return $row3['mid']; }
							foreach ($c as $row) {  array_push($array[4], $row); } //4
						} 
						$level++;  
						if ($level <= $levels)
						{
							$array[5] = array(); 
							foreach ($array[4] as $row4) 
							{ 
								$d = $this->_get_direct_downline($row4['mid']); 
								if (count($d) < $width) { return $row4['mid']; }
								foreach ($d as $row) {  array_push($array[5], $row); } //5
							} 
							$level++;  
							if ($level <= $levels)
							{
								$array[6] = array(); 
								foreach ($array[5] as $row5) 
								{ 
									$e = $this->_get_direct_downline($row5['mid']); 
									if (count($e) < $width) { return $row5['mid']; }
									foreach ($e as $row) {  array_push($array[6], $row); } //6
								} 
								$level++;  
								if ($level <= $levels)
								{
									$array[7] = array(); 
									foreach ($array[6] as $row6) 
									{ 
										$f = $this->_get_direct_downline($row6['mid']); 
										if (count($f) < $width) { return $row6['mid']; }
										foreach ($f as $row) {  array_push($array[7], $row); } //7
									} 
									$level++;  
									if ($level <= $levels)
									{
										$array[8] = array(); 
										foreach ($array[7] as $row7) 
										{ 
											$g = $this->_get_direct_downline($row7['mid']); 
											if (count($g) < $width) { return $row7['mid']; }
											foreach ($g as $row) {  array_push($array[8], $row); } //8
										} 
										$level++;  
										if ($level <= $levels)
										{
											$array[9] = array(); 
											foreach ($array[8] as $row8) 
											{ 
												$h = $this->_get_direct_downline($row8['mid']); 
												if (count($h) < $width) { return $row8['mid']; }
												foreach ($h as $row) {  array_push($array[9], $row); } //9
											} 
											$level++;  
											if ($level <= $levels)
											{
												$array[10] = array(); 
												foreach ($array[9] as $row9) 
												{ 
													$i = $this->_get_direct_downline($row9['mid']); 
													if (count($i) < $width) { return $row9['mid']; }
													foreach ($i as $row) {  array_push($array[9], $row); } //10
												} 
												$level++;  
											}		
										}		
									}		
								}	
							}	
						}	
					}
				}
			}
			else
			{
				return $sponsor;	
			}
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _get_direct_downline($sponsor = '')
	{
		$width = $this->config->item('sts_affiliate_mlm_matrix_width');
		
		$this->db->select('member_id as mid');
		$this->db->where('sponsor_id', $sponsor);
		$this->db->limit($width);
		$query = $this->db->get('members');
		
		if ($query->num_rows() > 0)
		{
			$a = $query->result_array();
		
			shuffle($a);
			
			return $a;
		}
		
	 	return array();
	}	
}
?>