<?php if (!defined('JROX_LICENSE_CHECK')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2007 - 2018 JROX Technologies, Inc. All Rights Reserved.
| -------------------------------------------------------------------------    
| This script may be only used and modified in accordance to the license      
   
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.
|
| -------------------------------------------------------------------------
| FILENAME - license_model.php
| -------------------------------------------------------------------------     
|
*/

class License_Model extends CI_Model {


    function _check_license($licensekey = '', $type = '')
    {

        // -----------------------------------
        //  -- Configuration Values --
        // -----------------------------------

        $localkey = $this->config->item('sts_local_key');
        $licensing_secret_key = JROX_LICENSE_CHECK;

        if ($type == 'mx')
        {
            $localkey = $this->config->item('sts_local_mx_key');
            $licensing_secret_key = JROX_MATRIX_CHECK;
        }
        // Enter the url to your WHMCS installation here
        $whmcsurl = JROX_CHECK_LICENSE_WEBSITE;
        // Must match what is specified in the MD5 Hash Verification field
        // of the licensing product that will be used with this check.

        // The number of days to wait between performing remote license checks
        $localkeydays = 15;
        // The number of days to allow failover for after local key expiry
        $allowcheckfaildays = 7;

        // -----------------------------------
        //  -- Do not edit below this line --
        // -----------------------------------

        $check_token = time() . md5(mt_rand(1000000000, 9999999999) . $licensekey);
        $checkdate = date("Ymd");
        $domain = $this->config->item('base_license_domain_name');
        $usersip = isset($_SERVER['SERVER_ADDR']) ? $_SERVER['SERVER_ADDR'] : $_SERVER['LOCAL_ADDR'];
        $dirpath = dirname(__FILE__);
        $verifyfilepath = 'modules/servers/licensing/verify.php';
        $localkeyvalid = false;
        if ($localkey) {
            $localkey = str_replace("\n", '', $localkey); # Remove the line breaks
            $localdata = substr($localkey, 0, strlen($localkey) - 32); # Extract License Data
            $md5hash = substr($localkey, strlen($localkey) - 32); # Extract MD5 Hash
            if ($md5hash == md5($localdata . $licensing_secret_key)) {
                $localdata = strrev($localdata); # Reverse the string
                $md5hash = substr($localdata, 0, 32); # Extract MD5 Hash
                $localdata = substr($localdata, 32); # Extract License Data
                $localdata = base64_decode($localdata);
                $localkeyresults = unserialize($localdata);
                $originalcheckdate = $localkeyresults['checkdate'];
                if ($md5hash == md5($originalcheckdate . $licensing_secret_key)) {
                    $localexpiry = date("Ymd", mktime(0, 0, 0, date("m"), date("d") - $localkeydays, date("Y")));
                    if ($originalcheckdate > $localexpiry) {
                        $localkeyvalid = true;
                        $results = $localkeyresults;
                        $validdomains = explode(',', $results['validdomain']);
                        $validips = explode(',', $results['validip']);
						$validdirs = explode(',', $results['validdirectory']);
						if (!in_array($_SERVER['SERVER_NAME'], $validdomains)) {
                            $localkeyvalid = false;
                            $localkeyresults['status'] = "Invalid";
                            $results = array();
                        }
                        if (!in_array($usersip, $validips)) {
                            $localkeyvalid = false;
                            $localkeyresults['status'] = "Invalid";
                            $results = array();
                        } 
                        if (!in_array($dirpath, $validdirs)) {
                            $localkeyvalid = false;
                            $localkeyresults['status'] = "Invalid";
                            $results = array();
                        }
                    }
                }
            }
        }
        if (!$localkeyvalid) {
            $postfields = array(
                'licensekey' => $licensekey,
                'domain' => $domain,
                'ip' => $usersip,
                'dir' => $dirpath,
            );
            if ($check_token) $postfields['check_token'] = $check_token;
            $query_string = '';
            foreach ($postfields AS $k=>$v) {
                $query_string .= $k.'='.urlencode($v).'&';
            }
            if (function_exists('curl_exec')) {
                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $whmcsurl . $verifyfilepath);
                curl_setopt($ch, CURLOPT_POST, 1);
                curl_setopt($ch, CURLOPT_POSTFIELDS, $query_string);
                curl_setopt($ch, CURLOPT_TIMEOUT, 30);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                $data = curl_exec($ch);

                curl_close($ch);
            } else {
                $fp = fsockopen($whmcsurl, 80, $errno, $errstr, 5);
                if ($fp) {
                    $newlinefeed = "\r\n";
                    $header = "POST ".$whmcsurl . $verifyfilepath . " HTTP/1.0" . $newlinefeed;
                    $header .= "Host: ".$whmcsurl . $newlinefeed;
                    $header .= "Content-type: application/x-www-form-urlencoded" . $newlinefeed;
                    $header .= "Content-length: ".@strlen($query_string) . $newlinefeed;
                    $header .= "Connection: close" . $newlinefeed . $newlinefeed;
                    $header .= $query_string;
                    $data = '';
                    @stream_set_timeout($fp, 20);
                    @fputs($fp, $header);
                    $status = @socket_get_status($fp);
                    while (!@feof($fp)&&$status) {
                        $data .= @fgets($fp, 1024);
                        $status = @socket_get_status($fp);
                    }
                    @fclose ($fp);
                }
            }
            if (!$data) {
                $localexpiry = date("Ymd", mktime(0, 0, 0, date("m"), date("d") - ($localkeydays + $allowcheckfaildays), date("Y")));
                if ($originalcheckdate > $localexpiry) {
                    $results = $localkeyresults;
                } else {
                    $results = array();
                    $results['status'] = "Invalid";
                    $results['description'] = "Remote Check Failed";
                    return $results;
                }
            } else {
                preg_match_all('/<(.*?)>([^<]+)<\/\\1>/i', $data, $matches);
                $results = array();
                foreach ($matches[1] AS $k=>$v) {
                    $results[$v] = $matches[2][$k];
                }
            }
            if (!is_array($results)) {
                die("Invalid License Server Response");
            }
            if (!empty($results['md5hash'])) {
                if ($results['md5hash'] != md5($licensing_secret_key . $check_token)) {
                    $results['status'] = "Invalid";
                    $results['description'] = "MD5 Checksum Verification Failed";
                    return $results;
                }
            }
            if ($results['status'] == "Active") {
                $results['checkdate'] = $checkdate;
                $data_encoded = serialize($results);
                $data_encoded = base64_encode($data_encoded);
                $data_encoded = md5($checkdate . $licensing_secret_key) . $data_encoded;
                $data_encoded = strrev($data_encoded);
                $data_encoded = $data_encoded . md5($data_encoded . $licensing_secret_key);
                $data_encoded = wordwrap($data_encoded, 80, "\n", true);
                $results['localkey'] = $data_encoded;
            }
            $results['remotecheck'] = true;
        }
        unset($postfields,$data,$matches,$whmcsurl,$licensing_secret_key,$checkdate,$usersip,$localkeydays,$allowcheckfaildays,$md5hash);

        if (!empty($results['remotecheck']))
        {
            if (!empty($results['status']))
            {
                switch($results['status'])
                {
                    case 'Active':

                        if ($type == 'mx')
                        {
                            $keys = array(
                                'sts_local_mx_key' => $results['localkey'],
                                'sts_mx_key'  =>  $licensekey,
                            );
                        }
                        else
                        {
                            $keys = array(
                                'sts_local_key' => $results['localkey'],
                                'sts_site_key'  =>  $licensekey,
                            );
                        }

                     break;

                    default:

                        if ($type == 'mx')
                        {
                            $keys = array(
                                'sts_local_mx_key' => '',
                                'sts_mx_key'  =>  '',
                            );
                        }
                        else
                        {
                            $keys = array(
                                'sts_local_key' => '',
                                'sts_site_key'  =>  '',
                            );
                        }
                    break;
                }

                $this->db_validation_model->_update_db_settings($keys);
            }
        }

        return $results;
    }

	// ------------------------------------------------------------------------
	
	function _generate_matrix_key($domain = '')
	{
		$check =  $this->security_model->_format_domain_name($domain);
		
		return 'AFFMX-' . strtoupper(sha1($check . JROX_MATRIX_TOKEN . JROX_KEY_FILE));
	}
	
	// ------------------------------------------------------------------------
	
	function _check_mx()
	{
		if (defined('JAM_ENABLE_SYSTEM_FSETTINGS') && JAM_ENABLE_SYSTEM_FSETTINGS == $this->config->item('sts_mx_key'))
		{
			return true;
		} 
		
		return false;
	}
	
	// ------------------------------------------------------------------------
	
	function _generate_license_key($domain = '')
	{
		$check = $this->security_model->_format_domain_name($domain);
		
		return 'AFF-' . strtoupper(md5($check . JROX_LICENSE_TOKEN . JROX_KEY_FILE));
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_rsl_updates() 
	{
		if (file_exists(BASEPATH.'application/hooks/db_settings_reseller.php'))
		{
			if (function_exists('curl_init'))
			{
				$license_values = array(
											'key_check' => JROX_LICENSE_TOKEN,
											'product' => 'jam',
											'domain_name' => $this->config->item('base_license_domain_name'),
											'folder_path' => $this->config->item('base_folder_path'),
											'license_key' => $this->config->item('sts_site_key'),
											'matrix_key' => $this->config->item('sts_mx_key'),
											'system_rs_config_data' => $this->config->item('system_rs_config_data'),
											'system_enable_gs_config' => $this->config->item('system_enable_gs_config'),
											'system_installation_id' => $this->config->item('sts_site_jam_installation_id'),
											'sytem_lc_type' => $this->config->item('sts_site_lc_type'),
										);
			
				$fields = "";
				foreach( $license_values as $key => $value ) $fields .= "$key=" . urlencode( $value ) . "&";
				
				$ch = curl_init(JROX_CHECK_LICENSE_WEBSITE);
				curl_setopt($ch, CURLOPT_HEADER, 0); // set to 0 to eliminate header info from response
				curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, '10');
			
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); // Returns response data instead of TRUE(1)
				curl_setopt($ch, CURLOPT_POSTFIELDS, rtrim( $fields, "& " )); // use HTTP POST to send form data
				
				curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // uncomment this line if you get no gateway response. ###
				
				if (CURL_PROXY_REQUIRED == true) {
					curl_setopt ($ch, CURLOPT_HTTPPROXYTUNNEL, CURL_PROXY_TUNNEL_FLAG);
					curl_setopt ($ch, CURLOPT_PROXYTYPE, CURLPROXY_HTTP);
					curl_setopt ($ch, CURLOPT_PROXY, CURL_PROXY_SERVER_DETAILS);
				}
				
				$resp = curl_exec($ch); //execute post and get results
				curl_close ($ch);
				
				if (!empty($resp))
				{
					$set_array = unserialize(base64_decode($resp));
					
					if (is_array($set_array))
					{						
						if (!empty($set_array['update_gs']))
						{
							$up['system_enable_gs_config'] = $set_array['new_gs_config'];
						
							$this->db_validation_model->_update_db_settings($up);
						}
						
						if (!empty($set_array['update_rs']))
						{
							$up['system_rs_config_data'] = $set_array['new_rs_config'];
						
							$this->db_validation_model->_update_db_settings($up);
						}
					}
				}
			}
			else
			{
				return 'curl must be enabled to run updates';
			}
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _validate_license($force = false, $update_reseller = false)
	{
		if ($update_reseller == false)
		{
			//if (!$this->config->item('sts_store_key')) return;
		}
		
		//set random check
		if ($force == true)
		{
			$i = '1';
		}
		else
		{
			$i = rand('1', '10');
		}
		
		
		if ($i < '7')
		{
			if (function_exists('curl_init'))
			{
				$license_values = array(
                                        'key_check' => JROX_LICENSE_CHECK,
                                        'product' => 'jam',
                                        'domain_name' => $this->config->item('base_license_domain_name'),
                                        'folder_path' => $this->config->item('base_folder_path'),
                                        'license_key' => $this->config->item('sts_site_key'),
                                        'matrix_key' => $this->config->item('sts_mx_key'),
                                        'system_rs_config_data' => $this->config->item('system_rs_config_data'),
                                        'system_enable_gs_config' => $this->config->item('system_enable_gs_config'),
                                        'system_installation_id' => $this->config->item('sts_site_jam_installation_id'),
                                        'sytem_lc_type' => $this->config->item('sts_site_lc_type'),
										);
			
				$fields = "";
				foreach( $license_values as $key => $value ) $fields .= "$key=" . urlencode( $value ) . "&";
				
				$ch = curl_init(JROX_CHECK_LICENSE_WEBSITE);
				curl_setopt($ch, CURLOPT_HEADER, 0); // set to 0 to eliminate header info from response
				curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, '10');
			
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); // Returns response data instead of TRUE(1)
				curl_setopt($ch, CURLOPT_POSTFIELDS, rtrim( $fields, "& " )); // use HTTP POST to send form data
				
				curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // uncomment this line if you get no gateway response. ###
				
				if (CURL_PROXY_REQUIRED == true) {
					curl_setopt ($ch, CURLOPT_HTTPPROXYTUNNEL, CURL_PROXY_TUNNEL_FLAG);
					curl_setopt ($ch, CURLOPT_PROXYTYPE, CURLPROXY_HTTP);
					curl_setopt ($ch, CURLOPT_PROXY, CURL_PROXY_SERVER_DETAILS);
				}
				
				$resp = curl_exec($ch); //execute post and get results
				curl_close ($ch); 
				 
				if (!empty($resp))
				{
					$set_array = unserialize(base64_decode($resp));
					//echo '<pre>'; print_r($set_array); exit();
					if (is_array($set_array))
					{
						if ($update_reseller == true)
						{
							if (!empty($set_array['update_rs']))
							{
								$up['system_rs_config_data'] = $set_array['new_rs_config'];
							
								$this->db_validation_model->_update_db_settings($up);
							}
							
							return true;
						}
						
						if (empty($set_array['valid'])) //invalid license
						{
							$up['sts_site_key'] = '';
							$up['sts_mx_key'] = '';
						
							$this->db_validation_model->_update_db_settings($up);
						}
						else
						{
							if (!empty($set_array['return_key']))
							{
								$up['sts_site_key'] = $set_array['return_key'];
							
								$this->db_validation_model->_update_db_settings($up);
							}
							
							if (!empty($set_array['return_mx_key']))
							{
								$up['sts_mx_key'] = $set_array['return_mx_key'];
							
								$this->db_validation_model->_update_db_settings($up);	
							}
						}
						
						if (!empty($set_array['update_gs']))
						{
							$up['system_enable_gs_config'] = $set_array['new_gs_config'];
						
							$this->db_validation_model->_update_db_settings($up);
						}
						
						if (!empty($set_array['update_rs']))
						{
							$up['system_rs_config_data'] = $set_array['new_rs_config'];
						
							$this->db_validation_model->_update_db_settings($up);
						}
					}
				}
			}
			else
			{
				show_error('curl must be enabled for JAM to run');
			}
		}
	}
}
?>